==> haskell-gauge-0.2.5-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gauge
version:              0.2.5
visibility:           public
id:                   gauge-0.2.5-Ih7YP2Q0QJ84XO8X5qV53b
key:                  gauge-0.2.5-Ih7YP2Q0QJ84XO8X5qV53b
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/vincenthz/hs-gauge
synopsis:             small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

category:             Development, Performance, Testing, Benchmarking
abi:                  095801b91f1911cf6c2ffea311a532db
exposed:              True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options

hidden-modules:
    Gauge.IO.Printf Gauge.Measurement Gauge.Monad Gauge.ListMap
    Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
    Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
    System.Random.MWC Paths_gauge Statistics.Distribution
    Statistics.Distribution.Normal Statistics.Function
    Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Transform Statistics.Types Statistics.Types.Internal
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum

import-dirs:          /usr/lib/ghc-8.10.3/site-local/gauge-0.2.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/gauge-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/gauge-0.2.5
hs-libraries:         HSgauge-0.2.5-Ih7YP2Q0QJ84XO8X5qV53b
depends:
    base-4.14.1.0 basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
    deepseq-1.4.4.0 directory-1.3.6.0 process-1.6.9.0
    vector-0.12.1.2-13ERBhpJHs04DSBWSaT2Mz

haddock-interfaces:   /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html:         /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gauge-0.2.5-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gauge
version:              0.2.5
visibility:           public
id:                   gauge-0.2.5-4RTGLWQ2ORkABX7OogzbXn
key:                  gauge-0.2.5-4RTGLWQ2ORkABX7OogzbXn
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/vincenthz/hs-gauge
synopsis:             small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

category:             Development, Performance, Testing, Benchmarking
abi:                  ee14894d36c60b7c57fc1c0ccf879032
exposed:              True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options

hidden-modules:
    Gauge.IO.Printf Gauge.Measurement Gauge.Monad Gauge.ListMap
    Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
    Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
    System.Random.MWC Paths_gauge Statistics.Distribution
    Statistics.Distribution.Normal Statistics.Function
    Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Transform Statistics.Types Statistics.Types.Internal
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum

import-dirs:          /usr/lib/ghc-8.10.3/site-local/gauge-0.2.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/gauge-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/gauge-0.2.5
hs-libraries:         HSgauge-0.2.5-4RTGLWQ2ORkABX7OogzbXn
depends:
    base-4.14.1.0 basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
    deepseq-1.4.4.0 directory-1.3.6.0 process-1.6.9.0
    vector-0.12.1.2-GaSyd0oSBV34z4313IZO9j

haddock-interfaces:   /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html:         /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
